nmrglue Package
===============

:mod:`bruker` Module
--------------------

.. automodule:: masai.fileio.nmrglue.bruker
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`fileiobase` Module
------------------------

.. automodule:: masai.fileio.nmrglue.fileiobase
    :members:
    :undoc-members:
    :show-inheritance:

